@@ -1,50 +1,5 @@
-HMR<-function(filename,series=NA,dec='.',sep=';',JPG=FALSE,PS=FALSE,PHMR=FALSE,npred=500,LR.always=FALSE,FollowHMR=FALSE,ngrid=1000,kappa.fixed=FALSE,show.message=TRUE)
+HMR<-function(filename,series=NA,dec='.',sep=';',JPG=FALSE,PS=FALSE,PHMR=FALSE,npred=500,LR.always=FALSE,FollowHMR=FALSE,ngrid=1000,kappa.fixed=FALSE)
 {
-  ## Version 0.4.1 starter med denne besked
-  HMRmessage<-function()
-  {
-    cat('',fill=TRUE)
-    cat('*********** IMPORTANT CHANGE WITH VERSION 0.4.1 ***********',fill=TRUE)
-    cat('',fill=TRUE)
-    cat('HMR version 0.4.1 comes with a new option, "kappa.fixed",',fill=TRUE)
-    cat('that affects the magnitude of the standard error of the',fill=TRUE)
-    cat('flux and the statistical significance.',fill=TRUE)
-    cat('',fill=TRUE)
-    cat('kappa.fixed=TRUE (default in previous versions)',fill=TRUE)
-    cat('----------------',fill=TRUE)
-    cat('With method HMR, the standard error of the flux is computed',fill=TRUE)
-    cat('by methods that assume that the estimated value of "kappa"',fill=TRUE)
-    cat('is fixed, ie. the estimation uncertainty of "kappa" is not',fill=TRUE)
-    cat('taken into account. PRO: This ensures comparability of the',fill=TRUE)
-    cat('standard errors and p-values between the three available',fill=TRUE)
-    cat('methods, because methods "LR" ("kappa"=0) and "No flux"',fill=TRUE)
-    cat('("kappa"=infinity) also discard the estimation uncertainty',fill=TRUE)
-    cat('of "kappa". This may be important in limiting cases, eg.',fill=TRUE)
-    cat('nearly linear data. CON: For non-linear data, the standard',fill=TRUE)
-    cat('error and the p-value are underestimated.',fill=TRUE)
-    cat('',fill=TRUE)
-    cat('kappa.fixed=FALSE (default in version 0.4.1)',fill=TRUE)
-    cat('-----------------',fill=TRUE)
-    cat('With method HMR, the standard error of the flux is computed',fill=TRUE)
-    cat('by methods that take the estimation uncertainty of "kappa"',fill=TRUE)
-    cat('into account. PRO: This ensures that the standard error and',fill=TRUE)
-    cat('p-value are not underestimated for non-linear data. CON:',fill=TRUE)
-    cat('The standard error and the p-value are not comparable',fill=TRUE)
-    cat('between the three available methods, because the "LR" and',fill=TRUE)
-    cat('"No flux" methods discard the estimation uncertainty of',fill=TRUE)
-    cat('"kappa". For nearly linear data, this may result in a',fill=TRUE)
-    cat('statistically insignificant non-linear flux and a',fill=TRUE)
-    cat('statistically significant linear flux; a difference that',fill=TRUE)
-    cat('may be attributed to different methods for calculating the',fill=TRUE)
-    cat('standard error and the p-value.',fill=TRUE)
-    cat('',fill=TRUE)
-    cat('NOTICE: The display of this message can be suppressed by',fill=TRUE)
-    cat('option "show.message=FALSE".',fill=TRUE)
-    cat('',fill=TRUE)
-    cat('*********** IMPORTANT CHANGE WITH VERSION 0.4.1 ***********',fill=TRUE)
-    cat('',fill=TRUE)
-  }
-
   ## Input
   ## -----
   ## filename    : En tekststreng indeholdende filnavnet. Det forudsttes, at datamappen i forvejen er sat med "setwd".
@@ -64,7 +19,6 @@ HMR<-function(filename,series=NA,dec='.',sep=';',JPG=FALSE,PS=FALSE,PHMR=FALSE,n
   ## ngrid       : Antal punkter i gittersgninger. Skal vre mindst 100. Default: 1000.
   ## kappa.fixed : Hvis "kappa.fixed=FALSE", indregnes estimationsusikkerheden for "kappa" i standard error for fluxen. Hvis
   ##               "kappa.fixed=TRUE", antages den estimerede vrdi af "kappa" for kendt. Default: FALSE.
-  ## show.message: Version 0.4.1 starter med en besked, som kan fravlges her (show.message=FALSE). Default: TRUE.
   
   ## Parametre - man pt. ikke kan ndre
   ## ----------------------------------
@@ -106,7 +60,7 @@ HMR<-function(filename,series=NA,dec='.',sep=';',JPG=FALSE,PS=FALSE,PHMR=FALSE,n
   ##   4. "sep" skal vre ";" eller ",". 
   ##   5. "dec" og "sep" m ikke begge vre ",".
   ##   6. "ngrid" og "npred" skal vre heltal, og "ngrid" skal vre mindst 100.
-  ##   7. "LR.always", "JPG", "PS", "PHMR", "FollowHMR", "kappa.fixed" og "show.message" skal vre "TRUE" eller "FALSE".
+  ##   7. "LR.always", "JPG", "PS", "PHMR", "FollowHMR" og "kappa.fixed" skal vre "TRUE" eller "FALSE".
   ##   8. "xtxt" og "ytxt" skal bare ikke vre "NULL".
 
   # Kontrollerer "filename"
@@ -130,8 +84,8 @@ HMR<-function(filename,series=NA,dec='.',sep=';',JPG=FALSE,PS=FALSE,PHMR=FALSE,n
               # Kontrollerer "ngrid" og "npred" - 2. gang
               if (!((xOK(ngrid))&(ngrid>=100)&(ngrid==floor(ngrid))&(ngrid==ceiling(ngrid))&(xOK(npred))&(npred>0)&(npred==floor(npred))&(npred==ceiling(npred)))) {FATAL<-TRUE} else
               {
-                # Kontrollerer "LR.always", "JPG", "PS", "PHMR", "FollowHMR", "kappa.fixed" og "show.message"
-                if (!(is.logical(show.message)&is.logical(kappa.fixed)&is.logical(FollowHMR)&is.logical(PHMR)&is.logical(LR.always)&is.logical(JPG)&is.logical(PS))) {FATAL<-TRUE} else
+                # Kontrollerer "LR.always", "JPG", "PS", "PHMR", "FollowHMR" og "kappa.fixed"
+                if (!(is.logical(kappa.fixed)&is.logical(FollowHMR)&is.logical(PHMR)&is.logical(LR.always)&is.logical(JPG)&is.logical(PS))) {FATAL<-TRUE} else
                 {
                   # Kontrollerer "xtxt" og "ytxt"
                   if (is.null(xtxt)|is.null(ytxt)) {FATAL<-TRUE} else
@@ -240,9 +194,6 @@ HMR<-function(filename,series=NA,dec='.',sep=';',JPG=FALSE,PS=FALSE,PHMR=FALSE,n
   ## Output
   if (FATAL) {Comment} else
   {
-    # Besked om vigtig ndring i version 0.4.1
-    if (show.message) {HMRmessage()}
-
     # Resultater
     oldOutDec<-getOption("OutDec"); options(OutDec=dec)
     OUTPUT<-OUTPUT[-1,]
